@@ -10,7 +10,7 @@ test_that('klfda visualization works', {
   r <- 3
   result <- klfda(k,y,r,metric="plain")
   options(rgl.useNULL=TRUE) # deal with rgl in Travis
-  expect_that(plot(result, iris[,5]), not(throws_error()))
+  plot(result, iris[,5])
 })
 
 test_that('lfda visualization works', {
@@ -21,7 +21,7 @@ test_that('lfda visualization works', {
   r <- 3
   result <- lfda(k,y,r,metric="plain")
   options(rgl.useNULL=TRUE) # deal with rgl in Travis
-  expect_that(plot(result, iris[,5]), not(throws_error()))
+  plot(result, iris[,5])
 })
 
 test_that('self visualization works', {
@@ -32,7 +32,7 @@ test_that('self visualization works', {
   r <- 3
   result <- self(X,Y,beta = 0.1, r = 3, metric = "plain")
   options(rgl.useNULL=TRUE) # deal with rgl in Travis
-  expect_that(plot(result, iris[,5]), not(throws_error()))
+  plot(result, iris[,5])
 })
 
 test_that('exceptions are caught in visualization function', {
@@ -43,11 +43,11 @@ test_that('exceptions are caught in visualization function', {
   r <- 3
   result <- lfda(k,y,r,metric="plain")
   options(rgl.useNULL=TRUE) # deal with rgl in Travis
-  expect_that(plot(result, iris[,5], cleanText=TRUE), not(throws_error()))
+  plot(result, iris[,5], cleanText=TRUE)
   expect_error(plot(result, iris[,1:5]))
   expect_error(plot(result, iris[1:10,5]))
   expect_error(plot(result, iris[,5], cleanText=3))
-  expect_that(plot(result, as.character(iris[,5])), not(throws_error()))
+  plot(result, as.character(iris[,5]))
   expect_warning(plot(lfda(k,y,4,metric="plain"), y))
   expect_error(plot(lfda(k,y,2,metric="plain"), y))
 })
